imblearn.under_sampling.EditedNearestNeighbours
===============================================

.. currentmodule:: imblearn.under_sampling

.. autoclass:: EditedNearestNeighbours

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~EditedNearestNeighbours.__init__
      ~EditedNearestNeighbours.fit
      ~EditedNearestNeighbours.fit_sample
      ~EditedNearestNeighbours.get_params
      ~EditedNearestNeighbours.sample
      ~EditedNearestNeighbours.set_params
   
   

   
   
   